@@ -41,12 +41,13 @@ class Event (Model):
     author = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='createdEvents', null=True, blank=True, on_delete=models.SET_NULL)
 
     class Meta : 
-        nested_fields=['type', 'circle']
-        ordering = ["startDate"]
-        anonymous_perms = ['view', 'add']
+        nested_fields=['type', 'circle', 'author', 'location']
+        ordering = ['startDate']
         auto_author = 'author'
         owner_field = 'author'
-        owner_perms = ['inherit','change','delete']
+        anonymous_perms = ['view']
+        authenticated_perms = ['inherit', 'add']
+        owner_perms = ['inherit', 'change', 'control', 'delete']
         
     def __str__(self):
         return self.name
